/*
 * Simple blog city -> MT (or WordPress via import) converter
 *
 * Copyright (C) 2006 Martin H. Smith
 *
 * Released under the terms of the GNU General Public License
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */

/*
 * MTFormatter.java
 *
 * Created on 26 February 2006, 16:31
 */

package com.alvermont.bcimport;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.TimeZone;

/**
 * Generates the output file in MoveableType format that can be imported by
 * WordPress.
 *
 * @author martin
 * @version $Id: MTFormatter.java,v 1.5 2006/02/27 10:32:53 martin Exp $
 */
public class MTFormatter
{
    /** Separator string between entries (posts) */
    public static final String ENTRY_SEPARATOR = "--------\n";
    /** Separator string between multi line fields within a post */
    public static final String FIELD_SEPARATOR = "-----\n";
    
    private SimpleDateFormat sdf;
    
    /** Creates a new instance of WordPressFormatter */
    public MTFormatter()
    {
        sdf = new SimpleDateFormat("MM/dd/yyyy hh:mm:ss a");
    }
    
    /**
     * Format a date into the correct output format. 
     *
     * @param date The date to be formatted
     * @return A string representation of the date in a suitable format
     */
    public String formatDate(Date date)
    {
        return sdf.format(date);
    }
   
    /**
     * Format a comment entry into a string for MT import
     * 
     * @param comment The comment to be formatted
     * @return A formatted string containing the comment
     */
    public String formatComment(Comment comment)
    {
        StringBuffer text = new StringBuffer();
        
        text.append("COMMENT:\n");
        text.append("AUTHOR: " + comment.getAuthor() + "\n");
        text.append("DATE: " + formatDate(comment.getPublished()) + "\n");
        text.append(comment.getText());
        text.append('\n');
        text.append(FIELD_SEPARATOR);
        
        return text.toString();
    }
    
    /**
     * Format a post entry into a string for MT import
     * 
     * @param post The comment to be formatted
     * @return A formatted string containing the post
     */
    public String formatPost(Post post)
    {
        StringBuffer text = new StringBuffer();
        
        text.append("TITLE: " + post.getTitle() + "\n");
        
        if (post.getAuthor() != null)
            text.append("AUTHOR: " + post.getAuthor() + "\n");
        
        text.append("DATE: " + formatDate(post.getPublished()) + "\n");
        text.append(FIELD_SEPARATOR);

        text.append("BODY:\n");
        text.append(post.getText());
        text.append('\n');
        text.append(FIELD_SEPARATOR);
        
        for (Comment comment : post.getComments())
        {
            text.append(formatComment(comment));
        }
        
        text.append(ENTRY_SEPARATOR);
        
        return text.toString();
    }
}
