/*
 * Simple blog city -> MT (or WordPress via import) converter
 *
 * Copyright (C) 2006 Martin H. Smith
 *
 * Released under the terms of the GNU General Public License
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */

/*
 * Main.java
 *
 * Created on 26 February 2006, 15:13
 */

package com.alvermont.bcimport;

import java.io.BufferedWriter;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import org.xml.sax.InputSource;
import org.xml.sax.XMLReader;
import org.xml.sax.helpers.XMLReaderFactory;

/**
 * Main class for the program.
 *
 * @author martin
 * @version $Id: Main.java,v 1.7 2006/02/27 10:32:53 martin Exp $
 */
public class Main
{    
    /** Creates a new instance of Main */
    public Main()
    {
    }
    
    /**
     * The entrypoint for the program.
     *
     * @param args the command line arguments
     */
    public static void main(String[] args)
    {
        if (args.length != 3)
        {
            System.err.println("BCImport Version " + AppConstants.PROGRAM_VERSION +
                    " released on " + AppConstants.RELEASE_DATE);
            System.err.println("By Martin Smith (martin at spamcop dot net)\n");
            System.err.println("Usage: java -jar bcimport.jar infile outfile author\n");
            System.err.println("To convert the XML file infile to the MT text format");
            System.err.println("in outfile. The specified author will be used for all ");
            System.err.println("top level posts. Comments will retain their original author\n");
            System.err.println("Example: java -jar bcimport.jar bc.xml import.txt MrFlibble");
            
            System.exit(1);
        }
        
        final BCHandler handler = new BCHandler();
        
        try
        {
            // create a reader and set up the content handler to parse it
            
            final XMLReader reader = XMLReaderFactory.createXMLReader();
            
            reader.setContentHandler(handler);
            
            // create an input source from the input file
            
            final InputStreamReader isr = new
                    InputStreamReader(new FileInputStream(args[0]));
            
            final InputSource is = new InputSource(isr);
            
            // parse the XML document and get a list of posts
            
            reader.parse(is);
            
            // create a writer to produce the output file
            
            final BufferedWriter bw = new BufferedWriter(
                    new OutputStreamWriter(new FileOutputStream(args[1])));
            
            // create a formatter to write the output format data
            
            final MTFormatter formatter = new MTFormatter();
            
            // iterate over each post, set the author and write it to the output
            
            for (Post p : handler.getPosts())
            {            
                p.setAuthor(args[2]);
                bw.write(formatter.formatPost(p));
            }
            
            // done
            
            bw.close();
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
            
            System.exit(1);
        }
    }
}
